// hb-game.c

#include <stdio.h>
#include <string.h>
#include "hb-game.h"

/*
	キーボードからプレーヤ名を入力させて、長さをチェックしてから、
	nameに格納する関数。
*/
void	inputPlayer(char* name, int nameLength, char* terminator)
{
	char inputBuff[256];	// 長めにバッファ確保
	do
	{
		printf("お名前は？（'%s'で終了）", terminator);
		scanf("%255s", inputBuff);
		if (nameLength - 1 < (int)strlen(inputBuff))
			printf("その名前は長すぎます。%d バイト以内で再入力してください \n", 
				nameLength - 1);
		// printf("名前の長さ%d \n", strlen(inputBuff));
	} while (nameLength - 1 < (int)strlen(inputBuff));
	strcpy(name, inputBuff);
}

/*
	入力した文字列が、ルールに適合するかチェックする関数。
	エラーなら0を、そうでないなら1を返す。
*/
int		validateInput(char* buff, int numInputs)
{
	int loop;
	if (numInputs != (int)strlen(buff))
	{
		printf("入力が %d 桁ではありません \n", numInputs);
		return 0;	// 長さerror
	}
	for (loop = 0; loop < numInputs; ++loop)
	{
		int loop2;
		if (!('0' <= buff[loop] && buff[loop] <= '9'))
		{
			printf("'%c'は数字ではありません \n", buff[loop]);
			return 0;	// 数字でないerror
		}
		for (loop2 = 0; loop2 < numInputs; ++loop2)
		{
			if (loop2 != loop && buff[loop] == buff[loop2])
			{
				printf("重複する数字を含んでいます（%c） \n", buff[loop]);
				return 0;	// 重複error
			}
		}
	}
	return 1;	// ok
}
int		getInputAsInt(char buff)
{
	return buff - '0';
}
/*
	数字の配列を、対応するintの配列に格納する。数値化するわけではない。
	'0', '1', '2' → 0, 1, 2
*/
void	getInputArray(char* input, int* intArray, int numInput)
{
	int loop;
	for (loop = 0; loop < numInput; ++loop)
	{
		intArray[loop] = getInputAsInt(input[loop]);
	}
}

/**
	キーボードから入力させて、値の妥当性をチェックしてから、
	intの配列（受け取るのはポインタ）に格納する。
*/
void	inputDigits(int countTrial, int* input, int inputLength)
{
	char inputBuff[50];
	// 入力
	do
	{
		printf("%d 桁の数字（ %d 回目）: ", inputLength, countTrial);
		scanf("%49s", inputBuff);
	} while (!validateInput(inputBuff, inputLength));
	getInputArray(inputBuff, input, inputLength);
}

/*
	入力の整数（input）と解答（answer）を比較して、成績を判定する関数。
	ルールの中核となるので、バグに注意。
*/
GamePoint	evaluate(int* input, int inputLength, int* answer, int answerLength)
{
	int inpLoop;
	int ansLoop;
	GamePoint pt = { 0, 0 };
	// 入力1回ごとの成績を判定する。
	// 重複がないため、単純2重ループが許される。
	for (inpLoop = 0; inpLoop < inputLength; ++inpLoop) 
	{
		for (ansLoop = 0; ansLoop < answerLength; ++ansLoop) 
		{
			if (inpLoop == ansLoop && input[inpLoop] == answer[ansLoop]) 
			{
				++pt.hits;
			} 
			else if (input[inpLoop] == answer[ansLoop]) 
			{
				++pt.blows;
			}
		}
	}
	return pt;
}
